
HEP Plugins for COBalD/TARDIS
=============================

.. image:: https://readthedocs.org/projects/cobald-hep-plugins/badge/?version=latest
    :target: http://cobald-hep-plugins.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation

.. image:: https://badges.gitter.im/MatterMiners.png
    :target: https://gitter.im/MatterMiners/community
    :alt: Development and Help Chat

.. image:: https://codecov.io/gh/MatterMiners/cobald-hep-plugins/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/MatterMiners/cobald-hep-plugins
    :alt: Test Coverage

.. image:: https://img.shields.io/pypi/v/cobald-hep-plugins.svg
    :alt: Available on PyPI
    :target: https://pypi.python.org/pypi/cobald-hep-plugins/

.. image:: https://img.shields.io/github/license/MatterMiners/cobald-hep-plugins.svg
    :alt: License
    :target: https://github.com/MatterMiners/cobald-hep-plugins/blob/master/LICENSE

.. toctree::
   :maxdepth: 2
   :caption: Available Plugins
   :hidden:

   plugins/stopper
   plugins/example

.. toctree::
   :maxdepth: 2
   :caption: Development & Maintenance
   :hidden:

   contributing

Official and third-party plugins for the `COBalD`_/`TARDIS`_ resource manager,
tailored for the needs of High Energy Physics and related domains.

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _COBalD: https://cobald.readthedocs.io
.. _TARDIS: https://cobald-tardis.readthedocs.io
